@@ -34,6 +34,7 @@ Archive::Entry::Entry(QObject *parent, const QString &fullPath, const QString &r
     , m_size(0)
     , m_compressedSize(0)
     , m_isDirectory(false)
+    , m_isExecutable(false)
     , m_isPasswordProtected(false)
 {
     if (!fullPath.isEmpty())
@@ -55,6 +56,7 @@ void Archive::Entry::copyMetaData(const Archive::Entry *sourceEntry)
     setProperty("link", sourceEntry->property("link"));
     setProperty("ratio", sourceEntry->property("ratio"));
     setProperty("CRC", sourceEntry->property("CRC"));
+    setProperty("BLAKE2", sourceEntry->property("BLAKE2"));
     setProperty("method", sourceEntry->property("method"));
     setProperty("version", sourceEntry->property("version"));
     setProperty("timestamp", sourceEntry->property("timestamp").toDateTime());
@@ -134,6 +136,16 @@ bool Archive::Entry::isDir() const
     return m_isDirectory;
 }
 
+void Archive::Entry::setIsExecutable(const bool isExecutable)
+{
+    m_isExecutable = isExecutable;
+}
+
+bool Archive::Entry::isExecutable() const
+{
+    return m_isExecutable;
+}
+
 int Archive::Entry::row() const
 {
     if (getParent()) {
