@@ -52,6 +52,7 @@ enum EntryMetaDataType {
     Group,               /**< The user group the entry belongs to */
     Ratio,               /**< The compression ratio for the entry */
     CRC,                 /**< The entry's CRC */
+    BLAKE2,              /**< The entry's BLAKE2 */
     Method,              /**< The compression method used on the entry */
     Version,             /**< The archiver version needed to extract the entry */
     Timestamp            /**< The timestamp for the current entry */
@@ -195,7 +196,7 @@ private:
     qulonglong m_numberOfFolders;
     qulonglong m_uncompressedSize;
 
-    // Whether a file entry has been listed. Used to ensure all relevent columns are shown,
+    // Whether a file entry has been listed. Used to ensure all relevant columns are shown,
     // since directories might have fewer columns than files.
     bool m_fileEntryListed;
 };
